<?php
/*
Plugin Name: DBD Login Style
Plugin URI: http://www.dontblinkdesign.com/
Description: This plugin enables you to specify a style sheet to be used on the login page. It also offers additional PDIV tag creation for custom messages.
Version: 1.1
Author: Don't Blink Design
Author URI: http://www.dontblinkdesign.com/
*/

class dbd_login_style
{
	var $default_settings;
	var $current_settings;
	var $errors;

	function dbd_login_style()
	{
		// Default Settings
		$this->default_settings = array(
			'dbd_ls_style_sheet' => '',
			'dbd_ls_head_url' => 'http://wordpress.org/',
			'dbd_ls_head_title' => 'Powered by WordPress',
			'dbd_ls_login_msg' => '',
			'dbd_ls_reg_msg' => '',
			'dbd_ls_pass_msg' => '',
			'dbd_ls_login_error_loggedout' => '',
			'dbd_ls_login_error_registerdiabled' => '',
			'dbd_ls_login_error_confirm' => '',
			'dbd_ls_login_error_newpass' => '',
			'dbd_ls_login_error_registered' => ''
			);

		// Manage form POSTs
		if ($_POST['dbd_ls_update'])
			$this->update_wpdb($_POST);

		// Set Default settings as current if no options in wpdb
		// Otherwise populate current settings from wpdb
		foreach($this->default_settings  as $label => $value)
		{
			if(!get_option($label))
			{
				add_option($label, $value);
				$this->current_settings[$label] = $value;
			}
			else
			{
				$this->current_settings[$label] = get_option($label);
			}
		}

		$this->add_hooks();
	}

	//gets value from current_settings array
	function g($key)
	{
		return stripslashes($this->current_settings[$key]);
	}

	//checks if keys array value is empty
	function e($key)
	{
		return empty($this->current_settings[$key]);
	}

	function update_wpdb($data)
	{
		global $wpdb;

		if($data)
		{
			foreach($data as $name => $value)
			{
				if(get_option($name) != $value)
					update_option($name, $value);
			}
		}
	}

	function add_hooks()
	{
		// Add Admin Menu
		add_action('admin_menu', array(&$this, 'admin_menu'));
		// Adds the CSS to the header
		add_action('login_head', array(&$this, 'add_style_sheet'));
		// Changes the Link URL
		add_filter('login_headerurl', array(&$this, 'change_head_url'));
		// Changes the Page Title
		add_filter('login_headertitle', array(&$this, 'change_head_title'));
		// Adds the a P tag to the Login Page
		add_action('login_form', array(&$this, 'add_login_msg'));
		// Adds the a P tag to the Registration Page
		add_action('register_form', array(&$this, 'add_register_msg'));
		// Adds the a P tag to the Lost Password Page
		add_action('lostpassword_form', array(&$this, 'add_lostpass_msg'));
	}

	function add_style_sheet()
	{
		$html = "<link rel=\"stylesheet\" type=\"text/css\" media=\"screen\" href=\"".get_bloginfo('wpurl')."/".$this->g('dbd_ls_style_sheet')."\" />\n";
		_e($html);
	}

	function change_head_url($s)
	{
		return $this->e('dbd_ls_head_url') ? $s : $this->g('dbd_ls_head_url');
	}

	function change_head_title($s)
	{
		$this->change_login_error_msgs();
		return $this->e('dbd_ls_head_title') ? $s : $this->g('dbd_ls_head_title');
	}

	function add_login_msg()
	{
		$html = '<div id="dbd_ls_log_form_msg">'.$this->g('dbd_ls_login_msg')."</div>\n";
		if (!$this->e('dbd_ls_login_msg'))
			_e($html);
	}

	function change_login_error_msgs()
	{
		global $errors;
		foreach ($errors as $k => $v)
		{
			if (!$this->e('dbd_ls_login_error_'.$k))
				$errors[$k] = $this->g('dbd_ls_login_error_'.$k);
		}
	}

	function add_register_msg()
	{
		$html = '<div id="dbd_ls_reg_form_msg">'.$this->g('dbd_ls_reg_msg')."</div>\n";
		if (!$this->e('dbd_ls_reg_msg'))
			_e($html);
	}

	function add_lostpass_msg()
	{
		$html = '<div id="dbd_ls_pass_form_msg">'.$this->g('dbd_ls_pass_msg')."</div>\n";
		if (!$this->e('dbd_ls_pass_msg'))
			_e($html);
	}

	// Manage Admin Options
	function admin_menu()
	{
		// Add admin page to the Presentation Tab of the admin section
		add_submenu_page('themes.php', 'Login Style Options', 'Login Style', 8, basename(__FILE__), array(&$this, 'admin_page'));
	}

	// Admin page
	function admin_page()
	{
		if ($_POST['dbd_ls_update'])
			_e('<div id="message" class="updated fade"><p>Login Syle Options Saved</p></div>');

		$html_hints = '<div class="wrap" id="html_hints">
<h2>XHTML Hints</h2>
<textarea cols="40" rows="5" disabled>
Link:
	<a href="http://url">Link</a>

Line Break:
	<br />

Ordered List:
	<ol>
		<li>Item 1</li>
		<li>Item 2</li>
	</ol>

Un-Ordered List:
	<ul>
		<li>Item</li>
		<li>Item</li>
	</ul>
</textarea>
</div>';
		//show styles
		_e('
			<style type="text/css">
				.ls_text_area
				{
					width: 600px;
					height: 200px;
				}

				.ls_text_box
				{
					width: 600px;
				}

				form#login_style label
				{
					font-weight: bold;
				}

				#html_hints
				{
					position: absolute;
					left: 670px;
					margin-top: -30px;
				}

				#html_hints textarea
				{
					background: #e3e3ea;
					color: #777;
					width: 280px;
					height: 300px;
					font-size: 12px;
					font-family: courier;
					padding: 15px;
				}
			</style>
		');

		//show form
		_e('
			<form id="login_style" method="post">
				<input type="hidden" name="dbd_ls_update" id="dbd_ls_update" value="dbd_ls_update" />

				<div class="wrap">
					<h2>Login Style General Options</h2>
					<p>
						<label for="dbd_ls_style_sheet">Style Sheet:</label><br />
						<input type="text" name="dbd_ls_style_sheet" id="dbd_ls_style_sheet" class="ls_text_box" value="'.$this->g('dbd_ls_style_sheet').'" />
					</p>
					<p>
						<label for="dbd_ls_head_url">Head Link URL:</label><br />
						<input type="text" name="dbd_ls_head_url" id="dbd_ls_head_url" class="ls_text_box" value="'.$this->g('dbd_ls_head_url').'" />
					</p>
					<p>
						<label for="dbd_ls_head_title">Head Link Title:</label><br />
						<input type="text" name="dbd_ls_head_title" id="dbd_ls_head_title" class="ls_text_box" value="'.$this->g('dbd_ls_head_title').'" />
					</p>
					<p><input type="submit" value="Save  &raquo;"></p>
				</div>
				<div class="wrap">
					<h2>Page Specific Messages</h2>
					'.$html_hints.'
					<p>
						<label for="dbd_ls_login_msg">Login Page Message:</label><br />
						<textarea name="dbd_ls_login_msg" id="dbd_ls_login_msg" cols="40" rows="5" class="code ls_text_area">'.$this->g('dbd_ls_login_msg').'</textarea>
					</p>
					<p>
						<label for="dbd_ls_reg_msg">Registration Page Message:</label><br />
						<textarea name="dbd_ls_reg_msg" id="dbd_ls_reg_msg" cols="40" rows="5" class="code ls_text_area">'.$this->g('dbd_ls_reg_msg').'</textarea>
					</p>
					<p>
						<label for="dbd_ls_pass_msg">Forgot Password Page Message:</label><br />
						<textarea name="dbd_ls_pass_msg" id="dbd_ls_pass_msg" cols="40" rows="5" class="code ls_text_area">'.$this->g('dbd_ls_pass_msg').'</textarea>
					</p>
					<br />
					<h2>Error Messages</h2>
					<p>
						<label for="dbd_ls_login_error_loggedout">Logged Out:</label><br />
						<input type="text" name="dbd_ls_login_error_loggedout" id="dbd_ls_login_error_loggedout" class="ls_text_box" value="'.$this->g('dbd_ls_login_error_loggedout').'" />
					</p>
					<p>
						<label for="dbd_ls_login_error_registerdiabled">Registration Disabled:</label><br />
						<input type="text" name="dbd_ls_login_error_registerdiabled" id="dbd_ls_login_error_registerdiabled" class="ls_text_box" value="'.$this->g('dbd_ls_login_error_registerdiabled').'" />
					</p>
					<p>
						<label for="dbd_ls_login_error_confirm">Confirmation Email:</label><br />
						<input type="text" name="dbd_ls_login_error_confirm" id="dbd_ls_login_error_confirm" class="ls_text_box" value="'.$this->g('dbd_ls_login_error_confirm').'" />
					</p>
					<p>
						<label for="dbd_ls_login_error_newpass">New Password:</label><br />
						<input type="text" name="dbd_ls_login_error_newpass" id="dbd_ls_login_error_newpass" class="ls_text_box" value="'.$this->g('dbd_ls_login_error_newpass').'" />
					</p>
					<p>
						<label for="dbd_ls_login_error_registered">Reg. Complete / Check Mail:</label><br />
						<input type="text" name="dbd_ls_login_error_registered" id="dbd_ls_login_error_registered" class="ls_text_box" value="'.$this->g('dbd_ls_login_error_registered').'" />
					</p>
					<p><input type="submit" value="Save  &raquo;"></p>
				</div>
			</form>
		');
	} // end function admin_page
} // end class

// Instantiate dbd_login_style class
$dbd_ls = new dbd_login_style();

?>